MediaGetterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • MediaGetterPlatform
Implementers

Constructors

MediaGetterPlatform()
Constructs a MediaGetterPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteFile({required String filePath}) Future<bool>
Deletes a file using its path via the native platform.
getAllAudios({DateTime? fromDate, int? limit, bool orderByDesc = true, bool sortBySize = false, bool sortByName = false, String? keyword}) Future<List<AudioModel>>
getAllDocuments({DateTime? fromDate, int? limit, bool orderByDesc = true, bool sortBySize = false, bool sortByName = false, String? keyword}) Future<List<FileModel>>
getAllFiles({DateTime? fromDate, int? limit, bool orderByDesc = true, bool sortBySize = false, bool sortByName = false, List<String> fileExtensions = const ['pdf', 'txt', 'zip'], String? keyword}) Future<List<FileModel>>
getAllImages({DateTime? fromDate, int? limit, bool orderByDesc = true, bool sortBySize = false, bool sortByName = false, String? keyword}) Future<List<ImageModel>>
getAllVideos({DateTime? fromDate, int? limit, bool orderByDesc = true, bool sortBySize = false, bool sortByName = false, String? keyword}) Future<List<VideoModel>>
getDCIM({DateTime? fromDate, int? limit, bool orderByDesc = true, bool sortBySize = false, bool sortByName = false, String? keyword}) Future<List>
Fetches media specific to the DCIM folder (Camera roll/captured content)
getDownloadFolderItems({DateTime? fromDate, int? limit, bool orderByDesc = true, bool sortBySize = false, bool sortByName = false, String? keyword}) Future<List<FileModel>>
getPlatformVersion() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showToast(String message, {ToastLength length = ToastLength.short}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance MediaGetterPlatform
The default instance of MediaGetterPlatform to use.
getter/setter pair